#ifndef KAPTIONGRAPHICSITEM_H
#define KAPTIONGRAPHICSITEM_H

#include <QGraphicsObject>
#include <QGraphicsDropShadowEffect>

class QAbstractGraphicsShapeItem;
class HandleGraphicsItem;
class Scale;

class KaptionGraphicsItem: public QGraphicsObject
{
public:
    KaptionGraphicsItem(QAbstractGraphicsShapeItem *shapeItem,
                        QGraphicsItem *parent = 0);

    virtual void setShapeColor(const QColor &color) = 0;
    virtual QColor shapeColor() const = 0;

    virtual void setShapeScale(const Scale &scale) = 0;
    virtual Scale shapeScale() const = 0;

    virtual void createShape(const QPointF &start, const QPointF &end) = 0;
    virtual void createShape(const QPointF &start,
                             const QPointF &end,
                             const Scale &scale) = 0;

    virtual KaptionGraphicsItem *copy() const = 0;

    virtual QRectF boundingRect() const;
    virtual void paint(QPainter *painter,
                       const QStyleOptionGraphicsItem *option,
                       QWidget *widget);

protected:
    virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
    void showHandles();
    void hideHandles();
    QAbstractGraphicsShapeItem *shapeItem() const;
    QGraphicsDropShadowEffect *dropShadowEffect() const;

    QList<HandleGraphicsItem*> m_handles;

private:
    Q_DISABLE_COPY(KaptionGraphicsItem)

    QAbstractGraphicsShapeItem *m_item;
};

inline
QRectF KaptionGraphicsItem::boundingRect() const
{
    return m_item->boundingRect();
}

inline
void KaptionGraphicsItem::paint(QPainter *painter,
                                       const QStyleOptionGraphicsItem *option,
                                       QWidget *widget)
{
    m_item->paint(painter, option, widget);
}

inline
QGraphicsDropShadowEffect *KaptionGraphicsItem::dropShadowEffect() const
{
    return static_cast<QGraphicsDropShadowEffect*>(m_item->graphicsEffect());
}

#endif // KAPTIONGRAPHICSITEM_H
