#ifndef SNAPSHOTCANVAS_H
#define SNAPSHOTCANVAS_H

#include <QGraphicsView>
#include "scale.h"

class QPixmap;
class QGraphicsScene;
class KaptionGraphicsItem;
class QPointF;
class QSize;
class QGraphicsDropShadowEffect;

class SnapshotCanvas : public QGraphicsView
{
    Q_OBJECT

public:

    enum GraphicItem {
        Arrow,
        Box,
        Text,
        Ellipse
    };

    explicit SnapshotCanvas(QWidget *parent = 0);
    ~SnapshotCanvas();

    void setPixmap(const QPixmap &pixmap);

    QFont textItemFont() const;

public Q_SLOTS:
    void setItemColor(const QColor &color);
    void setItemScale(const Scale &scale);
    void setTextItemFont(const QFont &font);
    void setItemToDraw(SnapshotCanvas::GraphicItem item);
    void deselectItems();

protected:
    virtual void resizeEvent(QResizeEvent *event);

private Q_SLOTS:
    void slotSelectionChanged();
    void slotDisableKeyboardEventsCapture();

private:
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void keyPressEvent(QKeyEvent *event);
    void addItem();
    void removeSelectedItems();
    void moveSelectedItemsBy(int dx, int dy);
    void adjustMaximumSize();
    void tryToConnectTextItem(KaptionGraphicsItem *item);

    QPointF m_origin;
    GraphicItem m_itemToDraw;
    KaptionGraphicsItem *m_currentDrawingItem;
    QGraphicsScene *m_scene;
    bool m_mouseDown;
    QColor m_color;
    QGraphicsPixmapItem *m_pixmapItem;
    QGraphicsDropShadowEffect *m_pixmapDropShadowEffect;
    Scale m_itemScale;
    QList<KaptionGraphicsItem*> m_itemsClipboard;
    bool m_captureKeyboardEvents;
    QFont m_font;
};

#endif // SNAPSHOTCANVAS_H
