#include "kaptionapplication.h"

#include <QSizePolicy>
#include <QDebug>
#include <QPixmap>
#include <QApplication>
#include <QDesktopWidget>
#include <KActionCollection>
#include <KMenu>
#include <KHelpMenu>
#include <QTimer>
#include <QLayout>
#include "trayicon.h"
#include "grabber.h"
#include "snapshotpreview.h"
#include "settings.h"
#include "configdialog/configdialog.h"

KaptionApplication::KaptionApplication()
    : KUniqueApplication(true, true)
{
    initGUI();
    QTimer::singleShot(0, this, SLOT(initObject()));
}

KaptionApplication::~KaptionApplication()
{
    if (m_preview) {
        m_preview->deleteLater();
    }
    delete m_trayIcon;
}

void KaptionApplication::initGUI()
{
    setQuitOnLastWindowClosed(false);
    m_trayIcon = new TrayIcon(this);
    setupTrayIcon();
}

void KaptionApplication::initObject()
{
    m_preview = 0;
}

void KaptionApplication::slotRegionGrabbed(const QPixmap &pixmap, const QPoint &topLeft)
{
    if (!pixmap.isNull()) {
        if (m_preview != 0) {
            m_preview->close();
        }
        m_preview = new SnapshotPreview();
        m_preview->setAttribute(Qt::WA_DeleteOnClose);
        m_preview->setPixmap(pixmap);
        m_preview->adjustSize();
        m_preview->move(topLeft);
        m_preview->show();
        m_preview->raise();
        m_preview->activateWindow();
    }

    slotQuitGrabber();
}

void KaptionApplication::slotQuitGrabber()
{
    /**
        @todo: This is ugly. It's useless to delete and create
               each time a new Grabber widget. But other way in Gnome
               it would not work, See grabber.cpp...it should
               be fixed there.
    */
    Grabber *g = dynamic_cast<Grabber*>(m_trayIcon->associatedWidget());
    if (g != 0) {
        g->close();
    }
    setupTrayIcon();
}

void KaptionApplication::slotConfigKaption(const QString &page)
{
    ConfigDialog *dialog = dynamic_cast<ConfigDialog*>(KConfigDialog::exists("settings"));
    if (!dialog) {
        dialog = new ConfigDialog(0, "settings", Settings::self());
    }
    dialog->show(page);
}

void KaptionApplication::setupTrayIcon()
{
    Grabber *grabber = new Grabber();
    grabber->setAttribute(Qt::WA_DeleteOnClose);
    m_trayIcon->setAssociatedWidget(grabber);

    connect(grabber, SIGNAL(regionGrabbed(QPixmap, QPoint)),
            this, SLOT(slotRegionGrabbed(QPixmap, QPoint)));
    connect(grabber, SIGNAL(quitRequested()),
            this, SLOT(slotQuitGrabber()));
}
