#include "scale.h"

Scale::Scale()
{
}

Scale::Scale(qreal min, qreal max)
    : m_min(min),
      m_max(max),
      m_pivot(calculateCenter(min, max)),
      m_value(min)
{
}

Scale::Scale(qreal min, qreal max, qreal pivot)
    : m_min(min),
      m_max(max),
      m_pivot(pivot),
      m_value(min)
{
}

Scale::Scale(const Scale &scale)
    : m_min(scale.min()),
      m_max(scale.max()),
      m_pivot(scale.pivot()),
      m_value(scale.value())
{
}

qreal Scale::min() const
{
    return m_min;
}

qreal Scale::max() const
{
    return m_max;
}

qreal Scale::pivot() const
{
    return m_pivot;
}

void Scale::setScale(qreal min, qreal max)
{
    setScale(min, max, calculateCenter(min, max));
}

void Scale::setScale(qreal min, qreal max, qreal pivot)
{
    m_min = min;
    m_max = max;
    m_pivot = pivot;
}

qreal Scale::value() const
{
    return m_value;
}

qreal Scale::value(qreal min, qreal max, qreal pivot) const
{
    if (m_min == min && m_max == max && m_pivot == pivot) {
        return value();
    }

    qreal value = 0;
    if (m_value >= m_pivot) {
        value = convert(m_value, m_pivot, m_max, pivot, max);
    }  else {
        value = convert(m_value, m_min, m_pivot, min, pivot);
    }
    return value;
}

void Scale::setValue(qreal value)
{
    m_value = value;
}
