// Here we avoid loading the header multiple times
#ifndef SNAPSHOTPREVIEW_H
#define SNAPSHOTPREVIEW_H

#include <QFrame>
#include <QPointer>

namespace Ui {
    class SnapshotPreview;
}

namespace KIO {
    class Job;
    class CopyJob;
}

class QIODevice;
class QByteArray;
class QGraphicsView;
class QGraphicsScene;
class QSignalMapper;
class KJob;
class KUrl;
class KTemporaryFile;
class UploadProgressDialog;
class QLabel;
class ShapeWidth;

class SnapshotPreview: public QFrame
{
    Q_OBJECT

public:
    explicit SnapshotPreview(QWidget *parent = 0);
    SnapshotPreview(const QPixmap &pixmap, QWidget *parent = 0);
    ~SnapshotPreview();

    void setPixmap(const QPixmap &pixmap);

protected:
    void showEvent(QShowEvent *e);
    void resizeEvent(QResizeEvent *e);

private Q_SLOTS:
    void slotUpload();
    void slotUploading(KJob *job, unsigned long percent);
    void slotUploadResult(KJob *job);
    void slotPrintUploadInfo(KJob *job, const QString &plain);
    void slotCancelUpload();
    void slotSaveAs();
    void slotUpdateEditingOption();
    void slotSetItemScale(int width);
    void slotOpenFontDlg();
    void setItemToDraw(int);

private:
    const static int ARROW   = 0;
    const static int BOX     = 1;
    const static int TEXT    = 2;
    const static int ELLIPSE = 3;

    void init();
    QPixmap getFinalPixmap() const;
    bool saveImage(QIODevice *device, const QByteArray &format);
    void setToolbarsMaxSize();

    KIO::CopyJob *m_currentJob;
    UploadProgressDialog *m_progressDialog;
    QPointer<KTemporaryFile> m_tmpFile;
    Ui::SnapshotPreview *ui;
    QSignalMapper *m_signalMapper;
};

#endif  //  SNAPSHOTPREVIEW_H

